<?php

namespace Drupal\poper\Form;

use Drupal\Core\Database\Connection;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Url;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form to add a popup entry.
 */
class PoperAddForm extends ConfigFormBase {

  use StringTranslationTrait;

  /**
   * Object of EntityTypeManager.
   *
   * @var EntityTypeManager
   */
  protected $typeManager;

  /**
   * Messanger object.
   *
   * @var Messenger
   */
  protected $messenger;

  /**
   * Database object.
   *
   * @var Connection
   */
  protected $database;

  /**
   * PoperAddForm constructor.
   *
   * @param EntityTypeManager $typeManager
   * @param Messenger $messenger
   * @param Connection $database
   */
  public function __construct(EntityTypeManager $typeManager, Messenger $messenger, Connection $database ) {
    $this->typeManager = $typeManager;
    $this->messenger = $messenger;
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
        $container->get('entity_type.manager'),
        $container->get('messenger'),
        $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'poper';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'poper.',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $uid = NULL) {
    $configFactory = \Drupal::service('config.factory');
    $data = $configFactory->get('poper.popup_'.$uid);

   $existing_email = $data->get('email');

  // Check if the email exists and display the alert.
  if (!empty($existing_email)) {
    $form['alert'] = [
      '#type' => 'markup',
      '#markup' => '<div class="alert alert-warning">' .
        $this->t('You are already connected to Poper with the email: @email.', ['@email' => $existing_email]) .
        '</div>',
    ];

    $form['redirect_button'] = [
      '#type' => 'link',
      '#title' => $this->t('Go to Poper'),
      '#url' => Url::fromUri('https://app.poper.ai/'),
      '#attributes' => [
        'class' => ['button', 'button--primary'],
        'target' => '_blank',
      ],
    ];
  }

      
    $form['video'] = [
     '#type' => 'inline_template',
     '#template' => '<div><iframe width="560" height="315" src="https://www.youtube.com/embed/videoseries?si=ioYIS9EAXBA8XjkY&amp;list=PLTC9PJO0DoIge9bx2pD228XlS3u6JudN3" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe></div>',
    ];
    
    $form['note'] = [
      '#type' => 'markup',
      '#markup' => '<p class="email-note">' . $this->t('Please enter the email address of your Poper account, or the one you intend to use:') . '</p>',
    ];
    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email Address'),
      '#required' => TRUE,
    ];
    

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];


    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = \Drupal::service('config.factory')->getEditable('poper.popup_'.$uid);
    
    // Save email
    $config->set('email', $form_state->getValue('email'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
